==> webkitgtk-2.8.5.tar.xz: webkitgtk-2.8.5/Source/WebCore/accessibility/AccessibilityMockObject.h <==
/*
 * Copyright (C) 2011 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE AND ITS CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE OR ITS CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef AccessibilityMockObject_h
#define AccessibilityMockObject_h

#include "AccessibilityObject.h"

namespace WebCore {
    
class AccessibilityMockObject : public AccessibilityObject {
    
protected:
    AccessibilityMockObject();
public:
    virtual ~AccessibilityMockObject();
    
    virtual AccessibilityObject* parentObject() const override { return m_parent; }
    virtual void setParent(AccessibilityObject* parent) { m_parent = parent; }
    virtual bool isEnabled() const override { return true; }

protected:
    AccessibilityObject* m_parent;

    // Must be called when the parent object clears its children.
    virtual void detachFromParent() override { m_parent = nullptr; }

private:
    virtual bool isMockObject() const override final { return true; }
    virtual bool isDetachedFromParent() { return !m_parent; }

    virtual bool computeAccessibilityIsIgnored() const override;
};

} // namespace WebCore 

SPECIALIZE_TYPE_TRAITS_ACCESSIBILITY(AccessibilityMockObject, isMockObject())

#endif // AccessibilityMockObject_h

==> webkitgtk-2.15.1.tar.xz: webkitgtk-2.15.1/Source/WebCore/accessibility/AccessibilityMockObject.h <==
/*
 * Copyright (C) 2011 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE AND ITS CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE OR ITS CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef AccessibilityMockObject_h
#define AccessibilityMockObject_h

#include "AccessibilityObject.h"

namespace WebCore {
    
class AccessibilityMockObject : public AccessibilityObject {
    
protected:
    AccessibilityMockObject();
public:
    virtual ~AccessibilityMockObject();
    
    AccessibilityObject* parentObject() const override { return m_parent; }
    virtual void setParent(AccessibilityObject* parent) { m_parent = parent; }
    bool isEnabled() const override { return true; }

protected:
    AccessibilityObject* m_parent;

    // Must be called when the parent object clears its children.
    void detachFromParent() override { m_parent = nullptr; }

private:
    bool isMockObject() const final { return true; }
    bool isDetachedFromParent() override { return !m_parent; }

    bool computeAccessibilityIsIgnored() const override;
};

} // namespace WebCore 

SPECIALIZE_TYPE_TRAITS_ACCESSIBILITY(AccessibilityMockObject, isMockObject())

#endif // AccessibilityMockObject_h
